@@ -1,4 +1,4 @@
-/* $Id: demowindow.cc,v 1.5 2004/02/26 22:28:22 murrayc Exp $ */
+/* $Id: demowindow.cc,v 1.11 2004/03/21 15:20:01 murrayc Exp $ */
 
 /* Copyright (C) 2001 The gtkmm Development Team
  *
@@ -31,6 +31,17 @@
 #include <cctype>
 #include <cerrno>
 
+//The SUN Forte compiler can't seem to either find the declarations or the implementations,
+//so these are not used on that platform.
+//#include <stdio.h> //Needed by the SUN Forte compiler, for flockfile().
+//SUN Forte seems to need these:
+//void flockfile(FILE*);
+//void funlockfile(FILE*);
+#ifdef GLIBMM_COMPILER_SUN_FORTE
+  //These don't wotk even though the configure-time check works.
+  #undef HAVE_FLOCKFILE
+  #undef HAVE_FUNLOCKFILE
+#endif
 
 namespace
 {
@@ -71,7 +82,7 @@ DemoWindow::DemoWindow()
 
   m_refTreeSelection = m_TreeView.get_selection();
   m_refTreeSelection->set_mode(Gtk::SELECTION_BROWSE);
-  m_refTreeSelection->set_select_function(&DemoWindow::select_function);
+  m_refTreeSelection->set_select_function( sigc::ptr_fun(&DemoWindow::select_function) );
 
   m_TreeView.set_size_request(200, -1);
 
@@ -161,7 +172,6 @@ void DemoWindow::on_treeview_row_activated(const Gtk::TreeModel::Path& path, Gtk
   }
 }
 
-// static
 bool DemoWindow::select_function(const Glib::RefPtr<Gtk::TreeModel>& model,
                                  const Gtk::TreeModel::Path& path, bool)
 {
@@ -295,7 +305,8 @@ void DemoWindow::load_file(const std::string& filename)
     	    {
     	      Gtk::TextBuffer::iterator end = start;
 
-    	      g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
+    	      // The SUN Forte compiler says this is a badly formed expression.
+            //g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
 
               const Glib::ustring strTemp (p, q);
     	      end = refBufferInfo->insert(end, strTemp);
@@ -338,7 +349,8 @@ void DemoWindow::load_file(const std::string& filename)
                       start = refBufferInfo->insert(start, " ");
                     }
 
-                  g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
+                  // The SUN Forte compiler says this is a badly formed expression.
+                  // g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
 
                   start = refBufferInfo->insert(start, Glib::ustring(p, p + len));
                   in_para = 1;
