@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.1 2003/01/04 14:40:14 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc,v 1.2 2004/02/10 14:49:34 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -50,9 +50,9 @@ ExampleWindow::ExampleWindow()
 
   
   //Connect signals:
-  m_Button_Quit.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_button_quit) );
-  m_Button_Buffer1.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_button_buffer1) );
-  m_Button_Buffer2.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_button_buffer2) );
+  m_Button_Quit.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_quit) );
+  m_Button_Buffer1.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_buffer1) );
+  m_Button_Buffer2.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_buffer2) );
   
   fill_buffers();
   on_button_buffer1();
@@ -62,32 +62,12 @@ ExampleWindow::ExampleWindow()
 
 void ExampleWindow::fill_buffers()
 {
-  //Create the first TextBuffer:
   m_refTextBuffer1 = Gtk::TextBuffer::create();
   m_refTextBuffer1->set_text("This is the text from TextBuffer #1.");
 
-  //Create a TagTable:
-  Glib::RefPtr<Gtk::TextBuffer::TagTable> refTagTable = m_refTextBuffer1->get_tag_table();
-  
-  //Apply color to some text.
-
-  //Create the tags:
-  Glib::RefPtr<Gtk::TextBuffer::Tag> refTagOrange = Gtk::TextBuffer::Tag::create("example-orange"); //We give it an arbitrary name.
-  refTagOrange->property_background() = "orange";
-  refTagTable->add(refTagOrange);
-
-  Glib::RefPtr<Gtk::TextBuffer::Tag> refTagBold = Gtk::TextBuffer::Tag::create("example-bold"); //We give it an arbitrary name.
-  refTagBold->property_weight() = Pango::WEIGHT_BOLD;
-  refTagTable->add(refTagBold);
-
-  //Use a tag:
-  m_refTextBuffer1->apply_tag(refTagOrange, m_refTextBuffer1->begin(), m_refTextBuffer1->get_iter_at_offset(4));
-
-  //Fill the second buffer, using the tags as we add the text:
-  m_refTextBuffer2 = Gtk::TextBuffer::create(refTagTable); //share the TagTable. A future gtkmm will have a set_tag_table() method.
+  m_refTextBuffer2 = Gtk::TextBuffer::create();
   m_refTextBuffer2->set_text("This is some alternative text, from TextBuffer #2.");
-  m_refTextBuffer2->insert_with_tag(m_refTextBuffer2->end(), "\nAnd here is some more", refTagOrange);
-  m_refTextBuffer2->insert_with_tag(m_refTextBuffer2->end(), "\nAnd some more.", refTagBold);
+
 }
 
 ExampleWindow::~ExampleWindow()
